| Title: | LINTUL Cassava crop growth simulation model |
|---|---|
| Description: | This package contains a fast implementation of the LINTUL crop growth model to simulate water-limited growth and development of cassava. The model was developed by Ezui et al. (2018) <doi:10.1016/j.fcr.2018.01.033> and callibrated by Adiele et al. (2021) <doi:10.1016/j.eja.2021.126242>. |
| Authors: | Guillaume Ezui [aut], Peter Leffelaar [aut], Rob van den Beuken [aut], Joy Adiele [aut], Tom Schut [aut], Robert J. Hijmans [cre, aut] |
| Maintainer: | Robert J. Hijmans <[email protected]> |
| License: | EUPL |
| Version: | 0.1-2 |
| Built: | 2026-05-25 07:28:55 UTC |
| Source: | https://github.com/cropmodels/LINTULcassava |
This package imlements the LINTUL-CASSAVA crop growth simulation model that was developed by
Ezui, K.S., P.A. Leffelaar, A.C. Franke, A. Mando & K.E. Giller (2018). Simulating drought impact and mitigation in cassava using the LINTUL model. Field Crops Research 219: 256-272. doi:10.1016/j.fcr.2018.01.033.
The model was calibrated with data from three locations in Nigeria by
Adiele, J.G., A.G.T. Schut, R.P.M. van den Beuken, K.S. Ezui, P. Pypers, A.O. Ano, C.N. Egesi & K.E. Giller (2021). A recalibrated and tested LINTUL-Cassava simulation model provides insight into the high yield potential of cassava under rainfed conditions. European Journal of Agronomy 124:126242. doi:10.1016/j.eja.2021.126242.
The orginal *R* implementation by Rob van den Beuken was a translation from the FST implementation of the model developed by Guillaume Ezui under supervision of Peter Leffelaar. Joy Adiele calibrated the model for Nigerian conditions using cultivar 'TME 419'. Tom Schut checked, simplified and adapted the code which is available as R scripts here (2024-10-21).
Robert Hijmans used the R scripts to create this R package. He tweaked the interface to make it easier to use, and he added an alternative R implementation of the model, as well as a C++ implementation that is more than 1000 times faster than the original R implementation.
Get example weather data, and soil, management and model control parameters from the Adiele et al study.
Adiele(site, year)Adiele(site, year)
site |
character. Site name. One of "Edo", "Cross River", or "Benue" |
year |
integer. Year. Either 2016 or 2017 |
list
Adiele, J.G., A.G.T. Schut, K.S. Ezui, P. Pypers and K.E. Giller (2021). A recalibrated and tested LINTUL-Cassava simulation model provides insight into the high yield potential of cassava under rainfed conditions. European Journal of Agronomy 124: 126242.
w <- Adiele("Edo", 2016) str(w)w <- Adiele("Edo", 2016) str(w)
Get crop parameters from by Ezui et al. or from by Adiele et al.
LC_crop(x)LC_crop(x)
x |
character. Either "Adiele" or "Ezui" |
list
Adiele, J.G., A.G.T. Schut, K.S. Ezui, P. Pypers and K.E. Giller (2021). A recalibrated and tested LINTUL-Cassava simulation model provides insight into the high yield potential of cassava under rainfed conditions. European Journal of Agronomy 124: 126242.
Ezui, K.S., P.A. Leffelaar, A.C. Franke, A. Mando, K.E. Giller (2018). Simulating drought impact and mitigation in cassava using the LINTUL model. Field Crops Research 219: 256-272.
crop <- LC_crop("Adiele") str(crop)crop <- LC_crop("Adiele") str(crop)
Run the LINTCAS model
LINTCAS(weather, crop, soil, management, control, level=3)LINTCAS(weather, crop, soil, management, control, level=3)
weather |
data.frame with weather data |
crop |
list with crop parameters |
soil |
list with soil parameters |
management |
list with management parameters (PLDATE, HVDATE) |
control |
list with model control parameters (starttime, timestep, IRRIGF) |
level |
1, 2, or 3. With 1 you get the original R implementation; 2 is a modified R implementation; and 3 is the C++ implementation). The results should be exactly the same. Level 2 is about 3 times faster than level 1, and level 3 is > 1000 times faster than level 1 |
data.frame
# get example parameters and environmental data crop <- LC_crop("Adiele") p <- Adiele("Edo", 2016) pot <- LINTCAS(p$weather, crop, p$soil, p$management, c(p$control, IRRIGF=TRUE)) wlm <- LINTCAS(p$weather, crop, p$soil, p$management, c(p$control, IRRIGF=FALSE)) tail(wlm)# get example parameters and environmental data crop <- LC_crop("Adiele") p <- Adiele("Edo", 2016) pot <- LINTCAS(p$weather, crop, p$soil, p$management, c(p$control, IRRIGF=TRUE)) wlm <- LINTCAS(p$weather, crop, p$soil, p$management, c(p$control, IRRIGF=FALSE)) tail(wlm)